DottedBorderOptions class sealed

Properties

borderPadding EdgeInsets
The padding between the dotted border and parent widget
final
borderType → BorderType?
The type of border to be drawn
final
color Color
The color of the dotted border. Will be overridden by gradient if provided
final
dashPattern List<double>
The dash pattern to be drawn. [1, 1] will draw a dash and a gap of 1 unit each.
final
gradient Gradient?
The gradient of the dotted border.
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
The padding between the dotted border and the child
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackFit StackFit
The fit provided to the parent stack
final
strokeCap StrokeCap
The strokeCap will determine the shape of the line endings for the border
final
strokeWidth double
The thickness of the dotted border
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited