OvalDottedBorderOptions class final

Provides options for drawing a dotted border with an oval.

Inheritance

Constructors

OvalDottedBorderOptions({EdgeInsets borderPadding = EdgeInsets.zero, EdgeInsets padding = const EdgeInsets.all(2), double strokeWidth = 1, Color color = Colors.black, Gradient? gradient, List<double> dashPattern = const <double>[3, 1], StackFit stackFit = StackFit.loose, StrokeCap strokeCap = StrokeCap.butt})
const

Properties

borderPadding EdgeInsets
The padding between the dotted border and parent widget
finalinherited
borderType → BorderType?
The type of border to be drawn
finalinherited
color Color
The color of the dotted border. Will be overridden by gradient if provided
finalinherited
dashPattern List<double>
The dash pattern to be drawn. [1, 1] will draw a dash and a gap of 1 unit each.
finalinherited
gradient Gradient?
The gradient of the dotted border.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
The padding between the dotted border and the child
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackFit StackFit
The fit provided to the parent stack
finalinherited
strokeCap StrokeCap
The strokeCap will determine the shape of the line endings for the border
finalinherited
strokeWidth double
The thickness of the dotted border
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited