PlayxBaseLogger class abstract

Abstract logger interface used by PlayxLogger. Can be implemented with any backend (e.g., Talker, Logger, etc.).

Constructors

PlayxBaseLogger({String? name})
Constructor for the logger.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Title of the logger.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

c(dynamic message, {String? tag}) → void
Alias for critical
critical(dynamic message, {String? tag}) → void
Logs a critical-level message.
d(dynamic message, {String? tag}) → void
Alias for debug
debug(dynamic message, {String? tag}) → void
Logs a debug-level message.
e(dynamic message, {Object? error, StackTrace? stackTrace, String? tag}) → void
Alias for error
error(dynamic message, {Object? error, StackTrace? stackTrace, String? tag}) → void
Logs an error-level message with optional exception and stack trace.
i(dynamic message, {String? tag}) → void
Alias for info
info(dynamic message, {String? tag}) → void
Logs an info-level message.
l(dynamic message, {String? tag}) → void
Alias for log
log(dynamic message, {String? tag}) → void
Logs a raw/unspecified-level message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
v(dynamic message, {String? tag}) → void
Alias for good
verbose(dynamic message, {String? tag}) → void
Logs a success/good message.
w(dynamic message, {String? tag}) → void
Alias for warning
warning(dynamic message, {String? tag}) → void
Logs a warning-level message.

Operators

operator ==(Object other) bool
The equality operator.
inherited