PlayxNavigationSettings class
Default navigation settings for Playx with support for both Navigator and Router.
The PlayxNavigationSettings class provides configuration options for navigation within an application. It supports traditional Navigator and modern Router configurations, as well as the GoRouter for advanced routing scenarios.
Note: The settings for Navigator, Router, and GoRouter are mutually exclusive. Use only one of these configurations at a time.
Constructors
-
Creates navigation settings for traditional Navigator navigation.
const
-
Creates navigation settings that use the GoRouter instead of Navigator.
const
-
Creates navigation settings that use the Router instead of Navigator.
const
Properties
- backButtonDispatcher → BackButtonDispatcher?
-
BackButtonDispatcher for Router-based navigation.
final
- builder → TransitionBuilder?
-
A builder function to wrap the entire navigation stack.
final
- config → PlayxPageConfig?
-
Optional global configuration for all
PlayxPageinstances when using GoRouter-based navigation.final - goRouter → GoRouter?
-
The GoRouter instance to use for advanced routing.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- home → Widget?
-
Default home widget for traditional navigation.
final
-
Whether to include the Sentry navigator observer.
Applicable only for traditional Navigator.
For Router-based navigation, add the Sentry observer to RouterDelegate.
final
- initialRoute → String?
-
The initial route to display when the app starts.
final
-
Key for managing the Navigator state.
final
-
List of NavigatorObservers to observe navigation events.
Applicable only for traditional Navigator.
For Router-based navigation, use the RouterDelegate.
final
- onGenerateInitialRoutes → InitialRouteListFactory?
-
Function for generating initial routes for traditional navigation.
final
- onGenerateRoute → RouteFactory?
-
Function for generating routes for traditional navigation.
final
- onUnknownRoute → RouteFactory?
-
Function for handling unknown routes for traditional navigation.
final
-
routeInformationParser
→ RouteInformationParser<
Object> ? -
RouteInformationParser for Router-based navigation.
final
- routeInformationProvider → RouteInformationProvider?
-
RouteInformationProvider for Router-based navigation.
final
-
routerDelegate
→ RouterDelegate<
Object> ? -
RouterDelegate for Router-based navigation.
final
-
routes
→ Map<
String, WidgetBuilder> ? -
Map of route names to WidgetBuilder functions for traditional navigation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useRouter → bool
-
Indicates whether to use Router-based navigation or GoRouter.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited