setBool static method

Future<void> setBool(
  1. String key,
  2. bool value
)

Sets the value associated with the given key as a bool.

  • key: The key under which the value will be stored.
  • value: The bool value to store.

Implementation

static Future<void> setBool(
  String key,
  bool value,
) =>
    sharedPrefs.setBool(key, value);