enableDrag property
Controls the draggability of the bottom sheet. This setting overrides the value provided via WoltModalSheet.show specifically for this page when the modal is displayed as a bottom sheet.
Implementation
final bool? enableDrag;
Controls the draggability of the bottom sheet. This setting overrides the value provided via WoltModalSheet.show specifically for this page when the modal is displayed as a bottom sheet.
final bool? enableDrag;