TalkerPlayxLogger class

Inheritance

Constructors

TalkerPlayxLogger({required PlayxLoggerSettings settings, String? name})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Title of the logger.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings PlayxLoggerSettings
final

Methods

c(dynamic message, {String? tag}) → void
Alias for critical
inherited
critical(dynamic message, {String? tag}) → void
Logs a critical-level message.
override
d(dynamic message, {String? tag}) → void
Alias for debug
inherited
debug(dynamic message, {String? tag}) → void
Logs a debug-level message.
override
e(dynamic message, {Object? error, StackTrace? stackTrace, String? tag}) → void
Alias for error
inherited
error(dynamic message, {Object? error, StackTrace? stackTrace, String? tag}) → void
Logs an error-level message with optional exception and stack trace.
override
i(dynamic message, {String? tag}) → void
Alias for info
inherited
info(dynamic message, {String? tag}) → void
Logs an info-level message.
override
l(dynamic message, {String? tag}) → void
Alias for log
inherited
log(dynamic message, {String? tag}) → void
Logs a raw/unspecified-level message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
v(dynamic message, {String? tag}) → void
Alias for good
inherited
verbose(dynamic message, {String? tag}) → void
Logs a success/good message.
override
w(dynamic message, {String? tag}) → void
Alias for warning
inherited
warning(dynamic message, {String? tag}) → void
Logs a warning-level message.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited