mainContentOutgoingSlidePositionCurve property
Curve for the slide position animation of the main content when it is outgoing. Defines the motion trajectory for exiting content.
Implementation
final Curve mainContentOutgoingSlidePositionCurve;
Curve for the slide position animation of the main content when it is outgoing. Defines the motion trajectory for exiting content.
final Curve mainContentOutgoingSlidePositionCurve;