ImageViewer class
Easily show an image from assets, network, cached network, or svg images.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ImageViewer
- Available extensions
Constructors
- ImageViewer.asset(String path, {Key? key, ErrorBuilder? errorBuilder, double? width, double? height, Color? color, BlendMode? colorBlendMode, BoxFit? fit = BoxFit.cover, AlignmentGeometry alignment = Alignment.center})
-
const
- ImageViewer.cachedNetwork(String src, {Key? key, double? width, double? height, BoxFit? fit = BoxFit.cover, AlignmentGeometry alignment = Alignment.center, Color? color, BlendMode? colorBlendMode, ErrorBuilder? errorBuilder, PlaceholderBuilder? placeholderBuilder, ImageRenderMethodForWeb imageRenderMethodForWeb = ImageRenderMethodForWeb.HttpGet})
-
const
- ImageViewer.file(File file, {Key? key, ErrorBuilder? errorBuilder, double? width, double? height, Color? color, BlendMode? colorBlendMode, BoxFit? fit = BoxFit.cover, AlignmentGeometry alignment = Alignment.center})
-
const
- ImageViewer.icon(IconInfo iconInfo, {Key? key, double? width, double? height, BoxFit? fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, Color? color, TextDirection? iconDirection, ImageRenderMethodForWeb imageRenderMethodForWeb = ImageRenderMethodForWeb.HttpGet})
-
const
- ImageViewer.memory(Uint8List bytes, {Key? key, ErrorBuilder? errorBuilder, double? width, double? height, Color? color, BlendMode? colorBlendMode, BoxFit? fit = BoxFit.cover, AlignmentGeometry alignment = Alignment.center})
-
const
- ImageViewer.network(String src, {Key? key, ErrorBuilder? errorBuilder, PlaceholderBuilder? placeholderBuilder, double? width, double? height, Color? color, BlendMode? colorBlendMode, BoxFit? fit = BoxFit.cover, AlignmentGeometry alignment = Alignment.center})
-
const
- ImageViewer.svgAsset(String path, {Key? key, double? width, double? height, BoxFit? fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, PlaceholderBuilder? placeholderBuilder, Clip? clipBehavior = Clip.hardEdge, Color? color, BlendMode? colorBlendMode})
-
const
- ImageViewer.svgMemory(Uint8List bytes, {Key? key, double? width, double? height, BoxFit? fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, PlaceholderBuilder? placeholderBuilder, Clip? clipBehavior = Clip.hardEdge, Color? color, BlendMode? colorBlendMode})
-
const
- ImageViewer.svgNetwork(String src, {Key? key, double? width, double? height, BoxFit? fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, PlaceholderBuilder? placeholderBuilder, Clip? clipBehavior = Clip.hardEdge, Color? color, BlendMode? colorBlendMode})
-
const
Properties
- alignment → AlignmentGeometry
-
How to align the image within its bounds.
final
- bytes → Uint8List?
-
final
- clipBehavior → Clip?
-
The content will be clipped (or not) according to this option.
final
- color → Color?
-
If non-null, this color is blended with each image pixel using colorBlendMode.
final
- colorBlendMode → BlendMode?
-
Used to combine color with this image.
final
- errorBuilder → ErrorBuilder?
-
A builder function that is called if an error occurs during image loading.
final
- file → File?
-
final
- fit → BoxFit?
-
How to inscribe the image into the space allocated during layout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
If non-null, require the image to have this height.
final
- iconDirection → TextDirection?
-
final
- iconInfo → IconInfo?
-
Icon info to be displayed.
final
- imageRenderMethodForWeb → ImageRenderMethodForWeb
-
Render options for images on the web platform for ImageViewer.cachedNetwork.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter - paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - path → String?
-
final
- placeholderBuilder → PlaceholderBuilder?
-
Widget displayed while the target is loading.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter - width → double?
-
If non-null, require the image to have this width.
final
Methods
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ImageViewer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited