ObjectRegistrationType enum
You will see a rather esoteric looking test (const Object() is! T) at several places.
It tests if T is a real type and not Object or dynamic.
For each registered factory/singleton an ObjectRegistration<T> is created
it holds either the instance of a Singleton or/and the creation functions
for creating an instance when get is called
There are three different types:
Values
- alwaysNew → const ObjectRegistrationType
- constant → const ObjectRegistrationType
- lazy → const ObjectRegistrationType
- cachedFactory → const ObjectRegistrationType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ObjectRegistrationType> - A constant List of the values in this enum, in order of their declaration.