setBool static method
Sets the value associated with the given key as a bool.
key: The key under which the value will be stored.value: Theboolvalue to store.
Implementation
static Future<void> setBool(
String key,
bool value,
) =>
sharedPrefs.setBool(key, value);